Enum agdb::QueryIds

source ·
pub enum QueryIds {
    Ids(Vec<QueryId>),
    Search(SearchQuery),
}
List of database ids used in queries. It can either represent a list of QueryIds or a search query. Search query allows query nesting and sourcing the ids dynamically for another query most commonly with the select queries.

Variants



Ids(Vec<QueryId>)

List of QueryIds



Search(SearchQuery)

Search query