Enum agdb::QueryValues
source · pub enum QueryValues {
Single(Vec<DbKeyValue>),
Multi(Vec<Vec<DbKeyValue>>),
}Expand description
Helper type distinguishing uniform (Single) values
and multiple (Multi) values in database queries.
Variants
Single(Vec<DbKeyValue>)
Single list of properties (key-value pairs) to be applied to all elements in a query.
Multi(Vec<Vec<DbKeyValue>>)
List of lists of properties (key-value pairs) to be applied to all elements in a query. There must be as many lists of properties as ids in a query.