SearchQueryAlgorithm

Enum SearchQueryAlgorithm 

pub enum SearchQueryAlgorithm {
    BreadthFirst,
    DepthFirst,
    Index,
    Elements,
}
Search algorithm to be used

Variants



BreadthFirst

Examines each distance level from the search origin in full before continuing with the next level. E.g. when starting at a node it first examines all the edges and then nodes they lead to.



DepthFirst

Examines maximum distance it can reach following every element. E.g. when starting at anode it will go edge -> node -> edge -> node until it reaches dead end or encounters already visited element.



Index

Bypasses the graph traversal and inspects only the index specified as the first condition (key).



Elements

Examines all elements in the database disregarding the graph structure or any relationship between the elements.