Struct agdb::QueryError
source · pub struct QueryError {
pub description: String,
pub cause: Option<DbError>,
}Expand description
Universal query error returned from all query operations.
It represents mainly errors from executing queries but the
cause of the error may be in exceptional cases a DbError.
Typically however it will contain description of a problem with
running a query such as “id/alias does not exist”.
Fields
description: Stringcause: Option<DbError>Trait Implementations
sourceimpl Debug for QueryError
impl Debug for QueryError
sourceimpl Default for QueryError
impl Default for QueryError
sourcefn default() -> QueryError
fn default() -> QueryError
Returns the “default value” for a type. Read more
sourceimpl Display for QueryError
impl Display for QueryError
sourceimpl Error for QueryError
impl Error for QueryError
sourcefn source(&self) -> Option<&(dyn Error + 'static)>
fn source(&self) -> Option<&(dyn Error + 'static)>
The lower-level source of this error, if any. Read more
1.0.0 · sourcefn description(&self) -> &str
fn description(&self) -> &str
👎Deprecated since 1.42.0: use the Display impl or to_string()
sourceimpl From<&str> for QueryError
impl From<&str> for QueryError
sourceimpl From<DbError> for QueryError
impl From<DbError> for QueryError
sourceimpl<T> From<PoisonError<T>> for QueryError
impl<T> From<PoisonError<T>> for QueryError
sourcefn from(value: PoisonError<T>) -> Self
fn from(value: PoisonError<T>) -> Self
Converts to this type from the input type.
sourceimpl From<String> for QueryError
impl From<String> for QueryError
sourceimpl PartialEq for QueryError
impl PartialEq for QueryError
sourcefn eq(&self, other: &QueryError) -> bool
fn eq(&self, other: &QueryError) -> bool
This method tests for
self and other values to be equal, and is used
by ==.impl StructuralPartialEq for QueryError