pub type DbMemoryTransaction<'a> = Transaction<'a, MemoryStorage>;Expand description
A convenience alias for the Transaction type for the default DbMemory.
Aliased Type
pub struct DbMemoryTransaction<'a> { /* private fields */ }pub type DbMemoryTransaction<'a> = Transaction<'a, MemoryStorage>;A convenience alias for the Transaction type for the default DbMemory.
pub struct DbMemoryTransaction<'a> { /* private fields */ }